# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageGridPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkSliceBySliceImageFilterPython
else:
    import _itkSliceBySliceImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterBPython

def itkSliceBySliceImageFilterICF3ICF3_New():
    return itkSliceBySliceImageFilterICF3ICF3.New()

class itkSliceBySliceImageFilterICF3ICF3(itk.itkImageToImageFilterBPython.itkImageToImageFilterICF3ICF3):
    r"""Proxy of C++ itkSliceBySliceImageFilterICF3ICF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSliceBySliceImageFilterICF3ICF3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSliceBySliceImageFilterICF3ICF3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_Clone(self)

    def SetDimension(self, _arg):
        r"""
        SetDimension(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_SetDimension(self, _arg)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetDimension(self)

    def SetFilter(self, filter):
        r"""
        SetFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterICF2ICF2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_SetFilter(self, filter)

    def GetFilter(self, *args):
        r"""
        GetFilter(self) -> itkImageToImageFilterICF2ICF2
        GetFilter(self) -> itkImageToImageFilterICF2ICF2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetFilter(self, *args)

    def SetInputFilter(self, filter):
        r"""
        SetInputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterICF2ICF2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_SetInputFilter(self, filter)

    def GetModifiableInputFilter(self):
        r"""GetModifiableInputFilter(self) -> itkImageToImageFilterICF2ICF2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetModifiableInputFilter(self)

    def GetInputFilter(self, *args):
        r"""
        GetInputFilter(self) -> itkImageToImageFilterICF2ICF2
        GetInputFilter(self) -> itkImageToImageFilterICF2ICF2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetInputFilter(self, *args)

    def SetOutputFilter(self, filter):
        r"""
        SetOutputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageSourceICF2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_SetOutputFilter(self, filter)

    def GetModifiableOutputFilter(self):
        r"""GetModifiableOutputFilter(self) -> itkImageSourceICF2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetModifiableOutputFilter(self)

    def GetOutputFilter(self, *args):
        r"""
        GetOutputFilter(self) -> itkImageSourceICF2
        GetOutputFilter(self) -> itkImageSourceICF2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetOutputFilter(self, *args)

    def GetSliceIndex(self):
        r"""GetSliceIndex(self) -> long"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_GetSliceIndex(self)
    __swig_destroy__ = _itkSliceBySliceImageFilterPython.delete_itkSliceBySliceImageFilterICF3ICF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSliceBySliceImageFilterICF3ICF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSliceBySliceImageFilterICF3ICF3

        Create a new object of the class itkSliceBySliceImageFilterICF3ICF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSliceBySliceImageFilterICF3ICF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSliceBySliceImageFilterICF3ICF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSliceBySliceImageFilterICF3ICF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSliceBySliceImageFilterICF3ICF3 in _itkSliceBySliceImageFilterPython:
_itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterICF3ICF3_swigregister(itkSliceBySliceImageFilterICF3ICF3)

def itkSliceBySliceImageFilterIF3IF3_New():
    return itkSliceBySliceImageFilterIF3IF3.New()

class itkSliceBySliceImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkSliceBySliceImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSliceBySliceImageFilterIF3IF3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSliceBySliceImageFilterIF3IF3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_Clone(self)

    def SetDimension(self, _arg):
        r"""
        SetDimension(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_SetDimension(self, _arg)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetDimension(self)

    def SetFilter(self, filter):
        r"""
        SetFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterIF2IF2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_SetFilter(self, filter)

    def GetFilter(self, *args):
        r"""
        GetFilter(self) -> itkImageToImageFilterIF2IF2
        GetFilter(self) -> itkImageToImageFilterIF2IF2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetFilter(self, *args)

    def SetInputFilter(self, filter):
        r"""
        SetInputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterIF2IF2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_SetInputFilter(self, filter)

    def GetModifiableInputFilter(self):
        r"""GetModifiableInputFilter(self) -> itkImageToImageFilterIF2IF2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetModifiableInputFilter(self)

    def GetInputFilter(self, *args):
        r"""
        GetInputFilter(self) -> itkImageToImageFilterIF2IF2
        GetInputFilter(self) -> itkImageToImageFilterIF2IF2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetInputFilter(self, *args)

    def SetOutputFilter(self, filter):
        r"""
        SetOutputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageSourceIF2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_SetOutputFilter(self, filter)

    def GetModifiableOutputFilter(self):
        r"""GetModifiableOutputFilter(self) -> itkImageSourceIF2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetModifiableOutputFilter(self)

    def GetOutputFilter(self, *args):
        r"""
        GetOutputFilter(self) -> itkImageSourceIF2
        GetOutputFilter(self) -> itkImageSourceIF2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetOutputFilter(self, *args)

    def GetSliceIndex(self):
        r"""GetSliceIndex(self) -> long"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_GetSliceIndex(self)
    __swig_destroy__ = _itkSliceBySliceImageFilterPython.delete_itkSliceBySliceImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSliceBySliceImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSliceBySliceImageFilterIF3IF3

        Create a new object of the class itkSliceBySliceImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSliceBySliceImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSliceBySliceImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSliceBySliceImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSliceBySliceImageFilterIF3IF3 in _itkSliceBySliceImageFilterPython:
_itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIF3IF3_swigregister(itkSliceBySliceImageFilterIF3IF3)

def itkSliceBySliceImageFilterIRGBUC3IRGBUC3_New():
    return itkSliceBySliceImageFilterIRGBUC3IRGBUC3.New()

class itkSliceBySliceImageFilterIRGBUC3IRGBUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBUC3IRGBUC3):
    r"""Proxy of C++ itkSliceBySliceImageFilterIRGBUC3IRGBUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSliceBySliceImageFilterIRGBUC3IRGBUC3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSliceBySliceImageFilterIRGBUC3IRGBUC3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_Clone(self)

    def SetDimension(self, _arg):
        r"""
        SetDimension(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_SetDimension(self, _arg)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetDimension(self)

    def SetFilter(self, filter):
        r"""
        SetFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterIRGBUC2IRGBUC2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_SetFilter(self, filter)

    def GetFilter(self, *args):
        r"""
        GetFilter(self) -> itkImageToImageFilterIRGBUC2IRGBUC2
        GetFilter(self) -> itkImageToImageFilterIRGBUC2IRGBUC2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetFilter(self, *args)

    def SetInputFilter(self, filter):
        r"""
        SetInputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterIRGBUC2IRGBUC2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_SetInputFilter(self, filter)

    def GetModifiableInputFilter(self):
        r"""GetModifiableInputFilter(self) -> itkImageToImageFilterIRGBUC2IRGBUC2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetModifiableInputFilter(self)

    def GetInputFilter(self, *args):
        r"""
        GetInputFilter(self) -> itkImageToImageFilterIRGBUC2IRGBUC2
        GetInputFilter(self) -> itkImageToImageFilterIRGBUC2IRGBUC2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetInputFilter(self, *args)

    def SetOutputFilter(self, filter):
        r"""
        SetOutputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageSourceIRGBUC2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_SetOutputFilter(self, filter)

    def GetModifiableOutputFilter(self):
        r"""GetModifiableOutputFilter(self) -> itkImageSourceIRGBUC2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetModifiableOutputFilter(self)

    def GetOutputFilter(self, *args):
        r"""
        GetOutputFilter(self) -> itkImageSourceIRGBUC2
        GetOutputFilter(self) -> itkImageSourceIRGBUC2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetOutputFilter(self, *args)

    def GetSliceIndex(self):
        r"""GetSliceIndex(self) -> long"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_GetSliceIndex(self)
    __swig_destroy__ = _itkSliceBySliceImageFilterPython.delete_itkSliceBySliceImageFilterIRGBUC3IRGBUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSliceBySliceImageFilterIRGBUC3IRGBUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSliceBySliceImageFilterIRGBUC3IRGBUC3

        Create a new object of the class itkSliceBySliceImageFilterIRGBUC3IRGBUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSliceBySliceImageFilterIRGBUC3IRGBUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSliceBySliceImageFilterIRGBUC3IRGBUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSliceBySliceImageFilterIRGBUC3IRGBUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSliceBySliceImageFilterIRGBUC3IRGBUC3 in _itkSliceBySliceImageFilterPython:
_itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIRGBUC3IRGBUC3_swigregister(itkSliceBySliceImageFilterIRGBUC3IRGBUC3)

def itkSliceBySliceImageFilterISS3ISS3_New():
    return itkSliceBySliceImageFilterISS3ISS3.New()

class itkSliceBySliceImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkSliceBySliceImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSliceBySliceImageFilterISS3ISS3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSliceBySliceImageFilterISS3ISS3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_Clone(self)

    def SetDimension(self, _arg):
        r"""
        SetDimension(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_SetDimension(self, _arg)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetDimension(self)

    def SetFilter(self, filter):
        r"""
        SetFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterISS2ISS2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_SetFilter(self, filter)

    def GetFilter(self, *args):
        r"""
        GetFilter(self) -> itkImageToImageFilterISS2ISS2
        GetFilter(self) -> itkImageToImageFilterISS2ISS2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetFilter(self, *args)

    def SetInputFilter(self, filter):
        r"""
        SetInputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterISS2ISS2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_SetInputFilter(self, filter)

    def GetModifiableInputFilter(self):
        r"""GetModifiableInputFilter(self) -> itkImageToImageFilterISS2ISS2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetModifiableInputFilter(self)

    def GetInputFilter(self, *args):
        r"""
        GetInputFilter(self) -> itkImageToImageFilterISS2ISS2
        GetInputFilter(self) -> itkImageToImageFilterISS2ISS2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetInputFilter(self, *args)

    def SetOutputFilter(self, filter):
        r"""
        SetOutputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageSourceISS2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_SetOutputFilter(self, filter)

    def GetModifiableOutputFilter(self):
        r"""GetModifiableOutputFilter(self) -> itkImageSourceISS2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetModifiableOutputFilter(self)

    def GetOutputFilter(self, *args):
        r"""
        GetOutputFilter(self) -> itkImageSourceISS2
        GetOutputFilter(self) -> itkImageSourceISS2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetOutputFilter(self, *args)

    def GetSliceIndex(self):
        r"""GetSliceIndex(self) -> long"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_GetSliceIndex(self)
    __swig_destroy__ = _itkSliceBySliceImageFilterPython.delete_itkSliceBySliceImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSliceBySliceImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSliceBySliceImageFilterISS3ISS3

        Create a new object of the class itkSliceBySliceImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSliceBySliceImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSliceBySliceImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSliceBySliceImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSliceBySliceImageFilterISS3ISS3 in _itkSliceBySliceImageFilterPython:
_itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterISS3ISS3_swigregister(itkSliceBySliceImageFilterISS3ISS3)

def itkSliceBySliceImageFilterIUC3IUC3_New():
    return itkSliceBySliceImageFilterIUC3IUC3.New()

class itkSliceBySliceImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkSliceBySliceImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSliceBySliceImageFilterIUC3IUC3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSliceBySliceImageFilterIUC3IUC3_Pointer"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_Clone(self)

    def SetDimension(self, _arg):
        r"""
        SetDimension(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_SetDimension(self, _arg)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetDimension(self)

    def SetFilter(self, filter):
        r"""
        SetFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterIUC2IUC2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_SetFilter(self, filter)

    def GetFilter(self, *args):
        r"""
        GetFilter(self) -> itkImageToImageFilterIUC2IUC2
        GetFilter(self) -> itkImageToImageFilterIUC2IUC2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetFilter(self, *args)

    def SetInputFilter(self, filter):
        r"""
        SetInputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageToImageFilterIUC2IUC2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_SetInputFilter(self, filter)

    def GetModifiableInputFilter(self):
        r"""GetModifiableInputFilter(self) -> itkImageToImageFilterIUC2IUC2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetModifiableInputFilter(self)

    def GetInputFilter(self, *args):
        r"""
        GetInputFilter(self) -> itkImageToImageFilterIUC2IUC2
        GetInputFilter(self) -> itkImageToImageFilterIUC2IUC2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetInputFilter(self, *args)

    def SetOutputFilter(self, filter):
        r"""
        SetOutputFilter(self, filter)

        Parameters
        ----------
        filter: itkImageSourceIUC2 *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_SetOutputFilter(self, filter)

    def GetModifiableOutputFilter(self):
        r"""GetModifiableOutputFilter(self) -> itkImageSourceIUC2"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetModifiableOutputFilter(self)

    def GetOutputFilter(self, *args):
        r"""
        GetOutputFilter(self) -> itkImageSourceIUC2
        GetOutputFilter(self) -> itkImageSourceIUC2
        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetOutputFilter(self, *args)

    def GetSliceIndex(self):
        r"""GetSliceIndex(self) -> long"""
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_GetSliceIndex(self)
    __swig_destroy__ = _itkSliceBySliceImageFilterPython.delete_itkSliceBySliceImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSliceBySliceImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSliceBySliceImageFilterIUC3IUC3

        Create a new object of the class itkSliceBySliceImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSliceBySliceImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSliceBySliceImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSliceBySliceImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSliceBySliceImageFilterIUC3IUC3 in _itkSliceBySliceImageFilterPython:
_itkSliceBySliceImageFilterPython.itkSliceBySliceImageFilterIUC3IUC3_swigregister(itkSliceBySliceImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def slice_by_slice_image_filter(*args: itkt.ImageLike,  dimension: int=..., filter=..., input_filter=..., output_filter=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for SliceBySliceImageFilter"""
    import itk

    kwarg_typehints = { 'dimension':dimension,'filter':filter,'input_filter':input_filter,'output_filter':output_filter }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.SliceBySliceImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def slice_by_slice_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageGrid.SliceBySliceImageFilter
    slice_by_slice_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    slice_by_slice_image_filter.__doc__ = filter_object.__doc__



